[![MIT Licence](https://badges.frapsoft.com/os/mit/mit.svg?v=103)](https://opensource.org/licenses/mit-license.php)
[![Maintenance](https://img.shields.io/badge/Maintained%3F-yes-green.svg)](https://GitHub.com/Naereen/StrapDown.js/graphs/commit-activity)
[![Ask Me Anything !](https://img.shields.io/badge/Ask%20me-anything-1abc9c.svg)](https://GitHub.com/Naereen/ama)

Python module used for importing and exporting data between Microsoft Excel workbook and MongoDB database.

**Requirements**
- Python 3.X
- pymongo 
- xlrd 


Be free to use, edit and redistribute this module under the MIT Licence.
